@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import copy
 import glob
 import importlib
@@ -66,7 +68,7 @@ class LazySettings(LazyObject):
         self.__resolve_config_aliases(kwargs)
         compat_kwargs(kwargs)
         self._kwargs = kwargs
-        super(LazySettings, self).__init__()
+        super().__init__()
 
         if wrapped:
             if self._django_override:
@@ -87,9 +89,9 @@ class LazySettings(LazyObject):
             "environment": "environments",
             "ENVIRONMENT": "ENVIRONMENTS",
         }
-        for mispell, correct in mispells.items():
-            if mispell in kwargs:
-                kwargs[correct] = kwargs.pop(mispell)
+        for misspell, correct in mispells.items():
+            if misspell in kwargs:
+                kwargs[correct] = kwargs.pop(misspell)
 
         for_dynaconf_keys = {
             key
@@ -178,7 +180,7 @@ class LazySettings(LazyObject):
         Allows user to reconfigure settings object passing a new settings
         module or separated kwargs
 
-        :param settings_module: defines the setttings file
+        :param settings_module: defines the settings file
         :param kwargs:  override default settings
         """
         default_settings.reload(self._should_load_dotenv)
@@ -207,7 +209,7 @@ class Settings:
     def __init__(self, settings_module=None, **kwargs):  # pragma: no cover
         """Execute loaders and custom initialization
 
-        :param settings_module: defines the setttings file
+        :param settings_module: defines the settings file
         :param kwargs:  override default settings
         """
         self._fresh = False
@@ -267,7 +269,7 @@ class Settings:
         """Allow `settings.FOO = 'value'` while keeping internal attrs."""
 
         if name in RESERVED_ATTRS:
-            super(Settings, self).__setattr__(name, value)
+            super().__setattr__(name, value)
         else:
             self.set(name, value)
 
@@ -275,7 +277,7 @@ class Settings:
         """stores reference in `_deleted` for proper error management"""
         self._deleted.add(name)
         if hasattr(self, name):
-            super(Settings, self).__delattr__(name)
+            super().__delattr__(name)
 
     def __contains__(self, item):
         """Respond to `item in settings`"""
@@ -344,7 +346,7 @@ class Settings:
         """
         value = self.get(item, empty)
 
-        # Yaml loader reads empty values as None, whould we apply defaults?
+        # Yaml loader reads empty values as None, would we apply defaults?
         global_apply_default = (
             self.get("APPLY_DEFAULT_ON_NONE_FOR_DYNACONF") is not None
         )
@@ -423,7 +425,7 @@ class Settings:
         parent=None,
     ):
         """
-        Get a value from settings store, this is the prefered way to access::
+        Get a value from settings store, this is the preferred way to access::
 
             >>> from dynaconf import settings
             >>> settings.get('KEY')
@@ -481,7 +483,7 @@ class Settings:
         """Check if key exists
 
         :param key: the name of setting variable
-        :param fresh: if key should be taken from source direclty
+        :param fresh: if key should be taken from source directly
         :return: Boolean
         """
         key = upperfy(key)
@@ -692,6 +694,7 @@ class Settings:
             return self.MAIN_ENV_FOR_DYNACONF.lower()
 
         if self.FORCE_ENV_FOR_DYNACONF is not None:
+            self.ENV_FOR_DYNACONF = self.FORCE_ENV_FOR_DYNACONF
             return self.FORCE_ENV_FOR_DYNACONF
 
         try:
@@ -902,7 +905,7 @@ class Settings:
 
         self.store[key] = value
         self._deleted.discard(key)
-        super(Settings, self).__setattr__(key, value)
+        super().__setattr__(key, value)
 
         # set loader identifiers so cleaners know which keys to clean
         if loader_identifier and loader_identifier in self.loaded_by_loaders:
@@ -1007,7 +1010,7 @@ class Settings:
         """Execute all internal and registered loaders
 
         :param env: The environment to load
-        :param silent: If loading erros is silenced
+        :param silent: If loading errors is silenced
         :param key: if provided load a single key
         :param filename: optional custom filename to load
         :param loaders: optional list of loader modules
@@ -1072,18 +1075,16 @@ class Settings:
                     # continue the loop.
                     continue
 
-                # python 3.6 does not resolve Pathlib basedirs
-                # issue #494
                 root_dir = str(self._root_path or os.getcwd())
+
+                # Issue #494
                 if (
                     isinstance(_filename, Path)
                     and str(_filename.parent) in root_dir
                 ):  # pragma: no cover
                     filepath = str(_filename)
                 else:
-                    filepath = os.path.join(
-                        self._root_path or os.getcwd(), str(_filename)
-                    )
+                    filepath = os.path.join(root_dir, str(_filename))
 
                 paths = [
                     p
@@ -1093,6 +1094,7 @@ class Settings:
                 local_paths = [
                     p for p in sorted(glob.glob(filepath)) if ".local." in p
                 ]
+
                 # Handle possible *.globs sorted alphanumeric
                 for path in paths + local_paths:
                     if path in already_loaded:  # pragma: no cover
@@ -1199,7 +1201,7 @@ class Settings:
         try:
             return copy.deepcopy(self)
         except TypeError:
-            # can't deepcopy settings object bacause of module object
+            # can't deepcopy settings object because of module object
             # being set as value in the settings dict
             new_data = self.to_dict(internal=True)
             new_data["dynaconf_skip_loaders"] = True
@@ -1215,7 +1217,7 @@ class Settings:
         internal methods and attrs.
         """
 
-        class AttrProxy(object):
+        class AttrProxy:
             def __init__(self, obj):
                 self.obj = obj
 
