@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 import importlib
-import io
 import os
 import pprint
 import sys
@@ -23,6 +24,7 @@ from dynaconf.validator import ValidationError
 from dynaconf.validator import Validator
 from dynaconf.vendor import click
 from dynaconf.vendor import toml
+from dynaconf.vendor import tomllib
 
 os.environ["PYTHONIOENCODING"] = "utf-8"
 
@@ -40,6 +42,8 @@ def set_settings(ctx, instance=None):
 
     settings = None
 
+    _echo_enabled = ctx.invoked_subcommand not in ["get", None]
+
     if instance is not None:
         if ctx.invoked_subcommand in ["init"]:
             raise click.UsageError(
@@ -50,10 +54,11 @@ def set_settings(ctx, instance=None):
     elif "FLASK_APP" in os.environ:  # pragma: no cover
         with suppress(ImportError, click.UsageError):
             from flask.cli import ScriptInfo  # noqa
+            from dynaconf import FlaskDynaconf
 
             flask_app = ScriptInfo().load_app()
-            settings = flask_app.config
-            click.echo(
+            settings = FlaskDynaconf(flask_app, **flask_app.config).settings
+            _echo_enabled and click.echo(
                 click.style(
                     "Flask app detected", fg="white", bg="bright_black"
                 )
@@ -69,7 +74,7 @@ def set_settings(ctx, instance=None):
             settings = LazySettings()
 
         if settings is not None:
-            click.echo(
+            _echo_enabled and click.echo(
                 click.style(
                     "Django app detected", fg="white", bg="bright_black"
                 )
@@ -96,7 +101,7 @@ def set_settings(ctx, instance=None):
 def import_settings(dotted_path):
     """Import settings instance from python dotted path.
 
-    Last item in dotted path must be settings instace.
+    Last item in dotted path must be settings instance.
 
     Example: import_settings('path.to.settings')
     """
@@ -160,7 +165,7 @@ def show_banner(ctx, param, value):
         return
     set_settings(ctx)
     click.echo(settings.dynaconf_banner)
-    click.echo("Learn more at: http://github.com/rochacbruno/dynaconf")
+    click.echo("Learn more at: http://github.com/dynaconf/dynaconf")
     ctx.exit()
 
 
@@ -258,6 +263,19 @@ def init(ctx, fileformat, path, env, _vars, _secrets, wg, y, django):
     """
     click.echo("⚙️  Configuring your Dynaconf environment")
     click.echo("-" * 42)
+    if "FLASK_APP" in os.environ:  # pragma: no cover
+        click.echo(
+            "⚠️  Flask detected, you can't use `dynaconf init` "
+            "on a flask project, instead go to dynaconf.com/flask/ "
+            "for more information.\n"
+            "Or add the following to your app.py\n"
+            "\n"
+            "from dynaconf import FlaskDynaconf\n"
+            "app = Flask(__name__)\n"
+            "FlaskDynaconf(app)\n"
+        )
+        exit(1)
+
     path = Path(path)
 
     if env is not None:
@@ -366,15 +384,14 @@ def init(ctx, fileformat, path, env, _vars, _secrets, wg, y, django):
         ignore_line = ".secrets.*"
         comment = "\n# Ignore dynaconf secret files\n"
         if not gitignore_path.exists():
-            with io.open(str(gitignore_path), "w", encoding=ENC) as f:
+            with open(str(gitignore_path), "w", encoding=ENC) as f:
                 f.writelines([comment, ignore_line, "\n"])
         else:
             existing = (
-                ignore_line
-                in io.open(str(gitignore_path), encoding=ENC).read()
+                ignore_line in open(str(gitignore_path), encoding=ENC).read()
             )
             if not existing:  # pragma: no cover
-                with io.open(str(gitignore_path), "a+", encoding=ENC) as f:
+                with open(str(gitignore_path), "a+", encoding=ENC) as f:
                     f.writelines([comment, ignore_line, "\n"])
 
         click.echo(
@@ -693,7 +710,16 @@ def validate(path):  # pragma: no cover
         click.echo(click.style(f"{path} not found", fg="white", bg="red"))
         sys.exit(1)
 
-    validation_data = toml.load(open(str(path)))
+    try:  # try tomlib first
+        validation_data = tomllib.load(open(str(path), "rb"))
+    except UnicodeDecodeError:  # fallback to legacy toml (TBR in 4.0.0)
+        warnings.warn(
+            "TOML files should have only UTF-8 encoded characters. "
+            "starting on 4.0.0 dynaconf will stop allowing invalid chars.",
+        )
+        validation_data = toml.load(
+            open(str(path), encoding=default_settings.ENCODING_FOR_DYNACONF),
+        )
 
     success = True
     for env, name_data in validation_data.items():
