@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import warnings
 from collections import ChainMap
 from contextlib import suppress
@@ -69,7 +71,7 @@ class FlaskDynaconf:
             app,
             ENV='MYSITE',
             SETTINGS_FILE='settings.yml',
-            EXTRA_VALUE='You can add aditional config vars here'
+            EXTRA_VALUE='You can add additional config vars here'
         )
 
     Take a look at examples/flask in Dynaconf repository
@@ -142,7 +144,7 @@ class DynaconfConfig(Config):
 
     def __init__(self, _settings, _app, *args, **kwargs):
         """perform the initial load"""
-        super(DynaconfConfig, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         # Bring Dynaconf instance value to Flask Config
         Config.update(self, _settings.store)
