@@ -5,13 +5,8 @@ import warnings
 from collections import defaultdict
 from json import JSONDecoder
 from typing import Any
-from typing import Dict
 from typing import Iterator
-from typing import List
-from typing import Optional
-from typing import Tuple
 from typing import TYPE_CHECKING
-from typing import Union
 
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -34,7 +29,7 @@ if os.name == "nt":  # pragma: no cover
 
 
 def object_merge(
-    old: Any, new: Any, unique: bool = False, full_path: List[str] = None
+    old: Any, new: Any, unique: bool = False, full_path: list[str] = None
 ) -> Any:
     """
     Recursively merge two data structures, new is mutated in-place.
@@ -51,32 +46,48 @@ def object_merge(
         return new
 
     if isinstance(old, list) and isinstance(new, list):
+
+        # 726: allow local_merge to override global merge on lists
+        if "dynaconf_merge_unique" in new:
+            new.remove("dynaconf_merge_unique")
+            unique = True
+
         for item in old[::-1]:
             if unique and item in new:
                 continue
             new.insert(0, item)
 
     if isinstance(old, dict) and isinstance(new, dict):
-        existing_value = recursive_get(old, full_path)  # doesnt handle None
+        existing_value = recursive_get(old, full_path)  # doesn't handle None
         # Need to make every `None` on `_store` to be an wrapped `LazyNone`
 
-        for key, value in old.items():
+        # data coming from source, in `new` can be mix case: KEY4|key4|Key4
+        # data existing on `old` object has the correct case: key4|KEY4|Key4
+        # So we need to ensure that new keys matches the existing keys
+        for new_key in list(new.keys()):
+            correct_case_key = find_the_correct_casing(new_key, old)
+            if correct_case_key:
+                new[correct_case_key] = new.pop(new_key)
 
+        for old_key, value in old.items():
+
+            # This is for when the dict exists internally
+            # but the new value on the end of full path is the same
             if (
                 existing_value is not None
-                and key.lower() == full_path[-1].lower()
+                and old_key.lower() == full_path[-1].lower()
                 and existing_value is value
             ):
                 # Here Be The Dragons
                 # This comparison needs to be smarter
                 continue
 
-            if key not in new:
-                new[key] = value
+            if old_key not in new:
+                new[old_key] = value
             else:
                 object_merge(
                     value,
-                    new[key],
+                    new[old_key],
                     full_path=full_path[1:] if full_path else None,
                 )
 
@@ -86,15 +97,15 @@ def object_merge(
 
 
 def recursive_get(
-    obj: Union[DynaBox, Dict[str, int], Dict[str, Union[str, int]]],
-    names: Optional[List[str]],
+    obj: DynaBox | dict[str, int] | dict[str, str | int],
+    names: list[str] | None,
 ) -> Any:
     """Given a dot accessible object and a list of names `foo.bar.zaz`
-    gets recursivelly all names one by one obj.foo.bar.zaz.
+    gets recursively all names one by one obj.foo.bar.zaz.
     """
     if not names:
         return
-    head, tail = names[0], names[1:]
+    head, *tail = names
     result = getattr(obj, head, None)
     if not tail:
         return result
@@ -102,7 +113,7 @@ def recursive_get(
 
 
 def handle_metavalues(
-    old: Union[DynaBox, Dict[str, int], Dict[str, Union[str, int]]], new: Any
+    old: DynaBox | dict[str, int] | dict[str, str | int], new: Any
 ) -> None:
     """Cleanup of MetaValues on new dict"""
 
@@ -111,7 +122,6 @@ def handle_metavalues(
         # MetaValue instances
         if getattr(new[key], "_dynaconf_reset", False):  # pragma: no cover
             # a Reset on `new` triggers reasign of existing data
-            # @reset is deprecated on v3.0.0
             new[key] = new[key].unwrap()
         elif getattr(new[key], "_dynaconf_del", False):
             # a Del on `new` triggers deletion of existing data
@@ -178,7 +188,7 @@ class DynaconfDict(dict):
         self._not_installed_warnings = []
         self._validate_only = kwargs.pop("validate_only", None)
         self._validate_exclude = kwargs.pop("validate_exclude", None)
-        super(DynaconfDict, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def set(self, key: str, value: str, *args, **kwargs) -> None:
         self[key] = value
@@ -208,7 +218,7 @@ RENAMED_VARS = {
 }
 
 
-def compat_kwargs(kwargs: Dict[str, Any]) -> None:
+def compat_kwargs(kwargs: dict[str, Any]) -> None:
     """To keep backwards compat change the kwargs to new names"""
     warn_deprecations(kwargs)
     for old, new in RENAMED_VARS.items():
@@ -230,7 +240,7 @@ class Missing:
         """Respond to boolean duck-typing."""
         return False
 
-    def __eq__(self, other: Union[DynaBox, Missing]) -> bool:
+    def __eq__(self, other: DynaBox | Missing) -> bool:
         """Equality check for a singleton."""
 
         return isinstance(other, self.__class__)
@@ -249,7 +259,7 @@ class Missing:
 missing = Missing()
 
 
-def deduplicate(list_object: List[str]) -> List[str]:
+def deduplicate(list_object: list[str]) -> list[str]:
     """Rebuild `list_object` removing duplicated and keeping order"""
     new = []
     for item in list_object:
@@ -269,8 +279,8 @@ def warn_deprecations(data: Any) -> None:
 
 
 def trimmed_split(
-    s: str, seps: Union[str, Tuple[str, str]] = (";", ",")
-) -> List[str]:
+    s: str, seps: str | tuple[str, str] = (";", ",")
+) -> list[str]:
     """Given a string s, split is by one of one of the seps."""
     for sep in seps:
         if sep not in s:
@@ -280,7 +290,7 @@ def trimmed_split(
     return [s]  # raw un-splitted
 
 
-def ensure_a_list(data: Any) -> Union[List[int], List[str]]:
+def ensure_a_list(data: Any) -> list[int] | list[str]:
     """Ensure data is a list or wrap it in a list"""
     if not data:
         return []
@@ -292,9 +302,7 @@ def ensure_a_list(data: Any) -> Union[List[int], List[str]]:
     return [data]
 
 
-def build_env_list(
-    obj: Union[Settings, LazySettings], env: Optional[str]
-) -> List[str]:
+def build_env_list(obj: Settings | LazySettings, env: str | None) -> list[str]:
     """Build env list for loaders to iterate.
 
     Arguments:
@@ -355,7 +363,7 @@ def upperfy(key: str) -> str:
     return key.upper()
 
 
-def multi_replace(text: str, patterns: Dict[str, str]) -> str:
+def multi_replace(text: str, patterns: dict[str, str]) -> str:
     """Replaces multiple pairs in a string
 
     Arguments:
@@ -372,7 +380,7 @@ def multi_replace(text: str, patterns: Dict[str, str]) -> str:
 
 def extract_json_objects(
     text: str, decoder: JSONDecoder = JSONDecoder()
-) -> Iterator[Dict[str, Union[int, Dict[Any, Any]]]]:
+) -> Iterator[dict[str, int | dict[Any, Any]]]:
     """Find JSON objects in text, and yield the decoded JSON data
 
     Does not attempt to look for JSON arrays, text, or other JSON types outside
@@ -393,7 +401,7 @@ def extract_json_objects(
 
 
 def recursively_evaluate_lazy_format(
-    value: Any, settings: Union[Settings, LazySettings]
+    value: Any, settings: Settings | LazySettings
 ) -> Any:
     """Given a value as a data structure, traverse all its members
     to find Lazy values and evaluate it.
@@ -431,3 +439,21 @@ def isnamedtupleinstance(value):
     if not isinstance(f, tuple):
         return False
     return all(type(n) == str for n in f)
+
+
+def find_the_correct_casing(key: str, data: dict[str, Any]) -> str | None:
+    """Given a key, find the proper casing in data
+
+    Arguments:
+        key {str} -- A key to be searched in data
+        data {dict} -- A dict to be searched
+
+    Returns:
+        str -- The proper casing of the key in data
+    """
+    if key in data:
+        return key
+    for k in data.keys():
+        if k.lower() == key.lower():
+            return k
+    return None
