@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import inspect
 import io
 import os
@@ -10,7 +12,7 @@ def _walk_to_root(path, break_at=None):
     Directories starting from the given directory up to the root or break_at
     """
     if not os.path.exists(path):  # pragma: no cover
-        raise IOError("Starting path not found")
+        raise OSError("Starting path not found")
 
     if os.path.isfile(path):  # pragma: no cover
         path = os.path.dirname(path)
@@ -28,7 +30,7 @@ def _walk_to_root(path, break_at=None):
     return paths
 
 
-SEARCHTREE = None
+SEARCHTREE = []
 
 
 def find_file(filename=".env", project_root=None, skip_files=None, **kwargs):
@@ -42,12 +44,18 @@ def find_file(filename=".env", project_root=None, skip_files=None, **kwargs):
     - Current working directory
 
     For each path in the `search_tree` it will also look for an
-    aditional `./config` folder.
+    additional `./config` folder.
     """
     search_tree = []
     work_dir = os.getcwd()
     skip_files = skip_files or []
 
+    # If filename is an absolute path and exists, just return it
+    # if the absolute path does not exist, return empty string so
+    # that it can be joined and avoid IoError
+    if os.path.isabs(filename):
+        return filename if os.path.exists(filename) else ""
+
     if project_root is not None:
         search_tree.extend(_walk_to_root(project_root, break_at=work_dir))
 
@@ -63,7 +71,7 @@ def find_file(filename=".env", project_root=None, skip_files=None, **kwargs):
     search_tree = deduplicate(search_tree)
 
     global SEARCHTREE
-    SEARCHTREE = search_tree
+    SEARCHTREE[:] = search_tree
 
     for dirname in search_tree:
         check_path = os.path.join(dirname, filename)
@@ -78,7 +86,7 @@ def find_file(filename=".env", project_root=None, skip_files=None, **kwargs):
 
 def read_file(path, **kwargs):
     content = ""
-    with io.open(path, **kwargs) as open_file:
+    with open(path, **kwargs) as open_file:
         content = open_file.read().strip()
     return content
 
