@@ -1,8 +1,8 @@
-# coding: utf-8
 # pragma: no cover
 """
 Implement basic assertions to be used in assertion action
 """
+from __future__ import annotations
 
 
 def eq(value, other):
@@ -53,3 +53,33 @@ def is_in(value, other):
 def is_not_in(value, other):
     """Inexistence"""
     return value not in other
+
+
+def cont(value, other):
+    """Contains"""
+    return other in value
+
+
+def len_eq(value, other):
+    """Length Equal"""
+    return len(value) == other
+
+
+def len_ne(value, other):
+    """Length Not equal"""
+    return len(value) != other
+
+
+def len_min(value, other):
+    """Minimum length"""
+    return len(value) >= other
+
+
+def len_max(value, other):
+    """Maximum length"""
+    return len(value) <= other
+
+
+def startswith(value, term):
+    """returns value.startswith(term) result"""
+    return value.startswith(term)
